@extends('layouts.app')

@section('title', 'تعديل المصرف - نظام إدارة الحوالات الخارجية')

@section('page-title', 'تعديل المصرف')

@section('page-actions')
<a href="{{ route('banks.show', $bank) }}" class="btn btn-secondary">
    <i class="bi bi-arrow-right"></i> العودة إلى تفاصيل المصرف
</a>
@endsection

@section('content')
<div class="row">
    <div class="col-md-8">
        <div class="card">
            <div class="card-header">
                <h5 class="mb-0">معلومات المصرف</h5>
            </div>
            <div class="card-body">
                <form action="{{ route('banks.update', $bank) }}" method="POST" enctype="multipart/form-data">
                    @csrf
                    @method('PUT')
                    
                    <div class="row mb-3">
                        <div class="col-md-6">
                            <label for="name" class="form-label">اسم المصرف (بالعربية) <span class="text-danger">*</span></label>
                            <input type="text" id="name" name="name" class="form-control @error('name') is-invalid @enderror" value="{{ old('name', $bank->name) }}" required>
                            @error('name')
                                <div class="invalid-feedback">{{ $message }}</div>
                            @enderror
                        </div>
                        
                        <div class="col-md-6">
                            <label for="name_en" class="form-label">اسم المصرف (بالإنجليزية) <span class="text-danger">*</span></label>
                            <input type="text" id="name_en" name="name_en" class="form-control @error('name_en') is-invalid @enderror" value="{{ old('name_en', $bank->name_en) }}" required>
                            @error('name_en')
                                <div class="invalid-feedback">{{ $message }}</div>
                            @enderror
                        </div>
                    </div>
                    
                    <div class="mb-3">
                        <label for="address" class="form-label">العنوان <span class="text-danger">*</span></label>
                        <textarea id="address" name="address" class="form-control @error('address') is-invalid @enderror" rows="2" required>{{ old('address', $bank->address) }}</textarea>
                        @error('address')
                            <div class="invalid-feedback">{{ $message }}</div>
                        @enderror
                    </div>
                    
                    <div class="mb-3">
                        <label for="swift_code" class="form-label">Swift Code <span class="text-danger">*</span></label>
                        <input type="text" id="swift_code" name="swift_code" class="form-control @error('swift_code') is-invalid @enderror" value="{{ old('swift_code', $bank->swift_code) }}" required>
                        @error('swift_code')
                            <div class="invalid-feedback">{{ $message }}</div>
                        @enderror
                    </div>
                    
                    <div class="mb-4">
                        <label for="logo" class="form-label">شعار المصرف</label>
                        @if($bank->logo)
                            <div class="mb-2">
                                <img src="{{ Storage::url($bank->logo) }}" alt="{{ $bank->name }}" class="img-thumbnail" style="max-height: 100px;">
                            </div>
                        @endif
                        <input type="file" id="logo" name="logo" class="form-control @error('logo') is-invalid @enderror" accept="image/*">
                        @error('logo')
                            <div class="invalid-feedback">{{ $message }}</div>
                        @enderror
                        <div class="form-text">الصيغة المسموح بها: JPG, PNG. الحجم الأقصى: 2MB</div>
                    </div>
                    
                    <div class="d-grid gap-2">
                        <button type="submit" class="btn btn-primary">
                            <i class="bi bi-save"></i> حفظ التغييرات
                        </button>
                    </div>
                </form>
            </div>
        </div>
    </div>
    
    <div class="col-md-4">
        <div class="card">
            <div class="card-header">
                <h5 class="mb-0">معلومات إضافية</h5>
            </div>
            <div class="card-body">
                <p><strong>تاريخ الإضافة:</strong> {{ $bank->created_at->format('Y-m-d H:i') }}</p>
                <p><strong>آخر تحديث:</strong> {{ $bank->updated_at->format('Y-m-d H:i') }}</p>
                <p><strong>عدد النماذج:</strong> {{ $bank->templates->count() }}</p>
                
                <hr>
                
                <div class="d-grid">
                    <a href="{{ route('banks.templates', $bank) }}" class="btn btn-outline-primary">
                        <i class="bi bi-file-earmark-text"></i> إدارة النماذج
                    </a>
                </div>
            </div>
        </div>
    </div>
</div>
@endsection