@extends('layouts.app')

@section('title', 'المصارف - نظام إدارة الحوالات الخارجية')

@section('page-title', 'المصارف')

@section('page-actions')
@can('create', App\Models\Bank::class)
<a href="{{ route('banks.create') }}" class="btn btn-primary">
    <i class="bi bi-plus-circle"></i> إضافة مصرف جديد
</a>
@endcan
@endsection

@section('content')
<div class="card">
    <div class="card-header">
        <h5 class="mb-0">قائمة المصارف</h5>
    </div>
    <div class="card-body">
        <div class="table-responsive">
            <table class="table table-hover">
                <thead>
                    <tr>
                        <th>#</th>
                        <th>الشعار</th>
                        <th>اسم المصرف</th>
                        <th>اسم المصرف (بالإنجليزية)</th>
                        <th>Swift Code</th>
                        <th>عدد النماذج</th>
                        <th>الإجراءات</th>
                    </tr>
                </thead>
                <tbody>
                    @forelse($banks as $index => $bank)
                        <tr>
                            <td>{{ $index + 1 }}</td>
                            <td>
                                @if($bank->logo)
                                    <img src="{{ Storage::url($bank->logo) }}" alt="{{ $bank->name }}" class="img-thumbnail" width="50">
                                @else
                                    <span class="badge bg-secondary">لا يوجد</span>
                                @endif
                            </td>
                            <td>{{ $bank->name }}</td>
                            <td>{{ $bank->name_en }}</td>
                            <td>{{ $bank->swift_code }}</td>
                            <td>{{ $bank->templates->count() }}</td>
                            <td>
                                <div class="btn-group btn-group-sm" role="group">
                                    <a href="{{ route('banks.show', $bank) }}" class="btn btn-info">
                                        <i class="bi bi-eye"></i>
                                    </a>
                                    <a href="{{ route('banks.templates', $bank) }}" class="btn btn-primary">
                                        <i class="bi bi-file-earmark-text"></i> النماذج
                                    </a>
                                    @can('update', $bank)
                                    <a href="{{ route('banks.edit', $bank) }}" class="btn btn-warning">
                                        <i class="bi bi-pencil"></i>
                                    </a>
                                    @endcan
                                    @can('delete', $bank)
                                    <button type="button" class="btn btn-danger" data-bs-toggle="modal" data-bs-target="#deleteModal{{ $bank->id }}">
                                        <i class="bi bi-trash"></i>
                                    </button>
                                    @endcan
                                </div>
                                
                                <!-- Delete Modal -->
                                @can('delete', $bank)
                                <div class="modal fade" id="deleteModal{{ $bank->id }}" tabindex="-1" aria-labelledby="deleteModalLabel{{ $bank->id }}" aria-hidden="true">
                                    <div class="modal-dialog">
                                        <div class="modal-content">
                                            <div class="modal-header">
                                                <h5 class="modal-title" id="deleteModalLabel{{ $bank->id }}">تأكيد الحذف</h5>
                                                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                                            </div>
                                            <div class="modal-body">
                                                هل أنت متأكد من رغبتك في حذف المصرف "{{ $bank->name }}"؟
                                            </div>
                                            <div class="modal-footer">
                                                <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">إلغاء</button>
                                                <form action="{{ route('banks.destroy', $bank) }}" method="POST">
                                                    @csrf
                                                    @method('DELETE')
                                                    <button type="submit" class="btn btn-danger">حذف</button>
                                                </form>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                                @endcan
                            </td>
                        </tr>
                    @empty
                        <tr>
                            <td colspan="7" class="text-center">لا توجد مصارف</td>
                        </tr>
                    @endforelse
                </tbody>
            </table>
        </div>
    </div>
</div>

<!-- Templates Stats -->
<div class="row mt-4">
    <div class="col-md-12">
        <div class="card">
            <div class="card-header">
                <h5 class="mb-0">إحصائيات النماذج</h5>
            </div>
            <div class="card-body">
                <div class="row">
                    <div class="col-md-8">
                        <div class="table-responsive">
                            <table class="table table-sm">
                                <thead>
                                    <tr>
                                        <th>المصرف</th>
                                        <th>طلب تحويل</th>
                                        <th>نافذة العملة</th>
                                        <th>تعهد</th>
                                        <th>تأكيد</th>
                                        <th>المجموع</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    @foreach($banks as $bank)
                                        <tr>
                                            <td>{{ $bank->name }}</td>
                                            <td>{{ $bank->templates->where('template_type', 'transfer_request')->count() }}</td>
                                            <td>{{ $bank->templates->where('template_type', 'currency_window')->count() }}</td>
                                            <td>{{ $bank->templates->where('template_type', 'covenant')->count() }}</td>
                                            <td>{{ $bank->templates->where('template_type', 'confirmation')->count() }}</td>
                                            <td><strong>{{ $bank->templates->count() }}</strong></td>
                                        </tr>
                                    @endforeach
                                </tbody>
                            </table>
                        </div>
                    </div>
                    <div class="col-md-4">
                        <div class="card">
                            <div class="card-body">
                                <h5 class="card-title">عدد النماذج حسب النوع</h5>
                                <ul class="list-group list-group-flush">
                                    <li class="list-group-item d-flex justify-content-between align-items-center">
                                        طلب تحويل
                                        <span class="badge bg-primary rounded-pill">{{ $templateStats['transfer_request'] ?? 0 }}</span>
                                    </li>
                                    <li class="list-group-item d-flex justify-content-between align-items-center">
                                        نافذة العملة
                                        <span class="badge bg-success rounded-pill">{{ $templateStats['currency_window'] ?? 0 }}</span>
                                    </li>
                                    <li class="list-group-item d-flex justify-content-between align-items-center">
                                        تعهد
                                        <span class="badge bg-warning rounded-pill">{{ $templateStats['covenant'] ?? 0 }}</span>
                                    </li>
                                    <li class="list-group-item d-flex justify-content-between align-items-center">
                                        تأكيد
                                        <span class="badge bg-info rounded-pill">{{ $templateStats['confirmation'] ?? 0 }}</span>
                                    </li>
                                </ul>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>
@endsection