@extends('layouts.app')

@section('title', 'تفاصيل المصرف - نظام إدارة الحوالات الخارجية')

@section('page-title', 'تفاصيل المصرف')

@section('page-actions')
<div class="btn-group" role="group">
    @can('update', $bank)
    <a href="{{ route('banks.edit', $bank) }}" class="btn btn-warning">
        <i class="bi bi-pencil"></i> تعديل
    </a>
    @endcan
    <a href="{{ route('banks.templates', $bank) }}" class="btn btn-primary">
        <i class="bi bi-file-earmark-text"></i> النماذج
    </a>
    <a href="{{ route('banks.index') }}" class="btn btn-secondary">
        <i class="bi bi-arrow-right"></i> العودة إلى المصارف
    </a>
</div>
@endsection

@section('content')
<div class="row">
    <div class="col-md-8">
        <div class="card mb-4">
            <div class="card-header">
                <h5 class="mb-0">معلومات المصرف</h5>
            </div>
            <div class="card-body">
                <div class="row mb-3">
                    <div class="col-md-6">
                        <label class="form-label fw-bold">اسم المصرف (بالعربية)</label>
                        <p>{{ $bank->name }}</p>
                    </div>
                    <div class="col-md-6">
                        <label class="form-label fw-bold">اسم المصرف (بالإنجليزية)</label>
                        <p>{{ $bank->name_en }}</p>
                    </div>
                </div>
                
                <div class="mb-3">
                    <label class="form-label fw-bold">العنوان</label>
                    <p>{{ $bank->address }}</p>
                </div>
                
                <div class="mb-3">
                    <label class="form-label fw-bold">Swift Code</label>
                    <p>{{ $bank->swift_code }}</p>
                </div>
            </div>
        </div>
        
        <div class="card">
            <div class="card-header d-flex justify-content-between align-items-center">
                <h5 class="mb-0">النماذج</h5>
                @can('create', App\Models\Template::class)
                <a href="{{ route('templates.create') }}?bank_id={{ $bank->id }}" class="btn btn-sm btn-primary">
                    <i class="bi bi-plus-circle"></i> إضافة نموذج
                </a>
                @endcan
            </div>
            <div class="card-body">
                @if($bank->templates->count() > 0)
                    <div class="table-responsive">
                        <table class="table table-hover">
                            <thead>
                                <tr>
                                    <th>#</th>
                                    <th>اسم النموذج</th>
                                    <th>النوع</th>
                                    <th>تاريخ الإضافة</th>
                                    <th>الإجراءات</th>
                                </tr>
                            </thead>
                            <tbody>
                                @foreach($bank->templates as $index => $template)
                                    <tr>
                                        <td>{{ $index + 1 }}</td>
                                        <td>{{ $template->name }}</td>
                                        <td>
                                            @if($template->template_type == 'transfer_request')
                                                <span class="badge bg-primary">طلب تحويل</span>
                                            @elseif($template->template_type == 'currency_window')
                                                <span class="badge bg-success">نافذة العملة</span>
                                            @elseif($template->template_type == 'covenant')
                                                <span class="badge bg-warning">تعهد</span>
                                            @elseif($template->template_type == 'confirmation')
                                                <span class="badge bg-info">تأكيد</span>
                                            @endif
                                        </td>
                                        <td>{{ $template->created_at->format('Y-m-d') }}</td>
                                        <td>
                                            <div class="btn-group btn-group-sm" role="group">
                                                <a href="{{ Storage::url($template->file_path) }}" class="btn btn-primary" target="_blank">
                                                    <i class="bi bi-eye"></i> عرض
                                                </a>
                                                @can('update', $template)
                                                <a href="{{ route('templates.edit', $template) }}" class="btn btn-warning">
                                                    <i class="bi bi-pencil"></i>
                                                </a>
                                                @endcan
                                            </div>
                                        </td>
                                    </tr>
                                @endforeach
                            </tbody>
                        </table>
                    </div>
                @else
                    <div class="alert alert-info">
                        لا توجد نماذج لهذا المصرف. 
                        @can('create', App\Models\Template::class)
                        <a href="{{ route('templates.create') }}?bank_id={{ $bank->id }}">إضافة نموذج جديد</a>
                        @endcan
                    </div>
                @endif
            </div>
        </div>
    </div>
    
    <div class="col-md-4">
        <div class="card mb-4">
            <div class="card-header">
                <h5 class="mb-0">شعار المصرف</h5>
            </div>
            <div class="card-body text-center">
                @if($bank->logo)
                    <img src="{{ Storage::url($bank->logo) }}" alt="{{ $bank->name }}" class="img-fluid" style="max-height: 200px;">
                @else
                    <div class="alert alert-secondary">
                        لا يوجد شعار للمصرف
                    </div>
                @endif
            </div>
        </div>
        
        <div class="card">
            <div class="card-header">
                <h5 class="mb-0">معلومات إضافية</h5>
            </div>
            <div class="card-body">
                <p><strong>تاريخ الإضافة:</strong> {{ $bank->created_at->format('Y-m-d H:i') }}</p>
                <p><strong>آخر تحديث:</strong> {{ $bank->updated_at->format('Y-m-d H:i') }}</p>
                <p><strong>عدد النماذج:</strong> {{ $bank->templates->count() }}</p>
            </div>
        </div>
    </div>
</div>
@endsection