@extends('layouts.app')

@section('title', 'تعديل المستفيد - نظام إدارة الحوالات الخارجية')

@section('page-title', 'تعديل المستفيد')

@section('page-actions')
<a href="{{ route('beneficiaries.show', $beneficiary) }}" class="btn btn-secondary">
    <i class="bi bi-arrow-right"></i> العودة إلى تفاصيل المستفيد
</a>
@endsection

@section('content')
<form action="{{ route('beneficiaries.update', $beneficiary) }}" method="POST">
    @csrf
    @method('PUT')
    
    <div class="row">
        <div class="col-md-8">
            <div class="card mb-4">
                <div class="card-header">
                    <h5 class="mb-0">معلومات المستفيد</h5>
                </div>
                <div class="card-body">
                    <div class="row mb-3">
                        <div class="col-md-6">
                            <label for="name" class="form-label">اسم المستفيد (بالعربية) <span class="text-danger">*</span></label>
                            <input type="text" id="name" name="name" class="form-control @error('name') is-invalid @enderror" value="{{ old('name', $beneficiary->name) }}" required>
                            @error('name')
                                <div class="invalid-feedback">{{ $message }}</div>
                            @enderror
                        </div>
                        
                        <div class="col-md-6">
                            <label for="name_en" class="form-label">اسم المستفيد (بالإنجليزية) <span class="text-danger">*</span></label>
                            <input type="text" id="name_en" name="name_en" class="form-control @error('name_en') is-invalid @enderror" value="{{ old('name_en', $beneficiary->name_en) }}" required>
                            @error('name_en')
                                <div class="invalid-feedback">{{ $message }}</div>
                            @enderror
                        </div>
                    </div>
                    
                    <div class="mb-3">
                        <label for="address" class="form-label">عنوان المستفيد <span class="text-danger">*</span></label>
                        <textarea id="address" name="address" class="form-control @error('address') is-invalid @enderror" rows="2" required>{{ old('address', $beneficiary->address) }}</textarea>
                        @error('address')
                            <div class="invalid-feedback">{{ $message }}</div>
                        @enderror
                    </div>
                    
                    <div class="row mb-3">
                        <div class="col-md-6">
                            <label for="country" class="form-label">الدولة <span class="text-danger">*</span></label>
                            <input type="text" id="country" name="country" class="form-control @error('country') is-invalid @enderror" value="{{ old('country', $beneficiary->country) }}" required>
                            @error('country')
                                <div class="invalid-feedback">{{ $message }}</div>
                            @enderror
                        </div>
                        
                        <div class="col-md-6">
                            <label for="city" class="form-label">المدينة <span class="text-danger">*</span></label>
                            <input type="text" id="city" name="city" class="form-control @error('city') is-invalid @enderror" value="{{ old('city', $beneficiary->city) }}" required>
                            @error('city')
                                <div class="invalid-feedback">{{ $message }}</div>
                            @enderror
                        </div>
                    </div>
                    
                    <div class="row mb-3">
                        <div class="col-md-6">
                            <label for="phone" class="form-label">رقم الهاتف</label>
                            <input type="text" id="phone" name="phone" class="form-control @error('phone') is-invalid @enderror" value="{{ old('phone', $beneficiary->phone) }}">
                            @error('phone')
                                <div class="invalid-feedback">{{ $message }}</div>
                            @enderror
                        </div>
                        
                        <div class="col-md-6">
                            <label for="email" class="form-label">البريد الإلكتروني</label>
                            <input type="email" id="email" name="email" class="form-control @error('email') is-invalid @enderror" value="{{ old('email', $beneficiary->email) }}">
                            @error('email')
                                <div class="invalid-feedback">{{ $message }}</div>
                            @enderror
                        </div>
                    </div>
                </div>
            </div>
            
            <div class="card mb-4">
                <div class="card-header">
                    <h5 class="mb-0">معلومات البنك المستفيد</h5>
                </div>
                <div class="card-body">
                    <div class="row mb-3">
                        <div class="col-md-6">
                            <label for="bank_name" class="form-label">اسم البنك <span class="text-danger">*</span></label>
                            <input type="text" id="bank_name" name="bank_name" class="form-control @error('bank_name') is-invalid @enderror" value="{{ old('bank_name', $beneficiary->bank_name) }}" required>
                            @error('bank_name')
                                <div class="invalid-feedback">{{ $message }}</div>
                            @enderror
                        </div>
                        
                        <div class="col-md-6">
                            <label for="bank_branch" class="form-label">اسم الفرع <span class="text-danger">*</span></label>
                            <input type="text" id="bank_branch" name="bank_branch" class="form-control @error('bank_branch') is-invalid @enderror" value="{{ old('bank_branch', $beneficiary->bank_branch) }}" required>
                            @error('bank_branch')
                                <div class="invalid-feedback">{{ $message }}</div>
                            @enderror
                        </div>
                    </div>
                    
                    <div class="mb-3">
                        <label for="bank_address" class="form-label">عنوان البنك <span class="text-danger">*</span></label>
                        <textarea id="bank_address" name="bank_address" class="form-control @error('bank_address') is-invalid @enderror" rows="2" required>{{ old('bank_address', $beneficiary->bank_address) }}</textarea>
                        @error('bank_address')
                            <div class="invalid-feedback">{{ $message }}</div>
                        @enderror
                    </div>
                    
                    <div class="row mb-3">
                        <div class="col-md-6">
                            <label for="bank_country" class="form-label">دولة البنك <span class="text-danger">*</span></label>
                            <input type="text" id="bank_country" name="bank_country" class="form-control @error('bank_country') is-invalid @enderror" value="{{ old('bank_country', $beneficiary->bank_country) }}" required>
                            @error('bank_country')
                                <div class="invalid-feedback">{{ $message }}</div>
                            @enderror
                        </div>
                        
                        <div class="col-md-6">
                            <label for="bank_city" class="form-label">مدينة البنك <span class="text-danger">*</span></label>
                            <input type="text" id="bank_city" name="bank_city" class="form-control @error('bank_city') is-invalid @enderror" value="{{ old('bank_city', $beneficiary->bank_city) }}" required>
                            @error('bank_city')
                                <div class="invalid-feedback">{{ $message }}</div>
                            @enderror
                        </div>
                    </div>
                    
                    <div class="row mb-3">
                        <div class="col-md-6">
                            <label for="account_number" class="form-label">رقم الحساب <span class="text-danger">*</span></label>
                            <input type="text" id="account_number" name="account_number" class="form-control @error('account_number') is-invalid @enderror" value="{{ old('account_number', $beneficiary->account_number) }}" required>
                            @error('account_number')
                                <div class="invalid-feedback">{{ $message }}</div>
                            @enderror
                        </div>
                        
                        <div class="col-md-6">
                            <label for="iban" class="form-label">IBAN <span class="text-danger">*</span></label>
                            <input type="text" id="iban" name="iban" class="form-control @error('iban') is-invalid @enderror" value="{{ old('iban', $beneficiary->iban) }}" required>
                            @error('iban')
                                <div class="invalid-feedback">{{ $message }}</div>
                            @enderror
                        </div>
                    </div>
                    
                    <div class="row mb-3">
                        <div class="col-md-6">
                            <label for="swift_code" class="form-label">Swift Code <span class="text-danger">*</span></label>
                            <input type="text" id="swift_code" name="swift_code" class="form-control @error('swift_code') is-invalid @enderror" value="{{ old('swift_code', $beneficiary->swift_code) }}" required>
                            @error('swift_code')
                                <div class="invalid-feedback">{{ $message }}</div>
                            @enderror
                        </div>
                        
                        <div class="col-md-6">
                            <label for="sort_code" class="form-label">Sort Code / ABA Number</label>
                            <input type="text" id="sort_code" name="sort_code" class="form-control @error('sort_code') is-invalid @enderror" value="{{ old('sort_code', $beneficiary->sort_code) }}">
                            @error('sort_code')
                                <div class="invalid-feedback">{{ $message }}</div>
                            @enderror
                        </div>
                    </div>
                    
                    <div class="mb-3">
                        <label for="additional_details" class="form-label">معلومات إضافية</label>
                        <textarea id="additional_details" name="additional_details" class="form-control @error('additional_details') is-invalid @enderror" rows="3">{{ old('additional_details', $beneficiary->additional_details) }}</textarea>
                        @error('additional_details')
                            <div class="invalid-feedback">{{ $message }}</div>
                        @enderror
                    </div>
                </div>
            </div>
        </div>
        
        <div class="col-md-4">
            <div class="card">
                <div class="card-body">
                    <div class="d-grid gap-2">
                        <button type="submit" class="btn btn-primary btn-lg">
                            <i class="bi bi-save"></i> حفظ التغييرات
                        </button>
                        <a href="{{ route('beneficiaries.show', $beneficiary) }}" class="btn btn-outline-secondary">
                            <i class="bi bi-x-circle"></i> إلغاء
                        </a>
                    </div>
                </div>
            </div>
        </div>
    </div>
</form>
@endsection