@extends('layouts.app')

@section('title', 'المستفيدين - نظام إدارة الحوالات الخارجية')

@section('page-title', 'المستفيدين')

@section('page-actions')
<a href="{{ route('beneficiaries.create') }}" class="btn btn-primary">
    <i class="bi bi-plus-circle"></i> إضافة مستفيد جديد
</a>
@endsection

@section('content')
<div class="card">
    <div class="card-header">
        <div class="row">
            <div class="col-md-6">
                <h5 class="mb-0">قائمة المستفيدين</h5>
            </div>
            <div class="col-md-6">
                <form method="GET" action="{{ route('beneficiaries.index') }}" class="d-flex">
                    <input type="text" name="search" class="form-control form-control-sm me-2" placeholder="بحث..." value="{{ request('search') }}">
                    <select name="country" class="form-select form-select-sm me-2">
                        <option value="">كل الدول</option>
                        @foreach($countries as $country)
                            <option value="{{ $country }}" {{ request('country') == $country ? 'selected' : '' }}>{{ $country }}</option>
                        @endforeach
                    </select>
                    <button type="submit" class="btn btn-sm btn-primary">
                        <i class="bi bi-search"></i>
                    </button>
                </form>
            </div>
        </div>
    </div>
    <div class="card-body">
        <div class="table-responsive">
            <table class="table table-hover">
                <thead>
                    <tr>
                        <th>#</th>
                        <th>اسم المستفيد</th>
                        <th>الدولة</th>
                        <th>المصرف</th>
                        <th>رقم الحساب</th>
                        <th>Swift Code</th>
                        <th>الإجراءات</th>
                    </tr>
                </thead>
                <tbody>
                    @forelse($beneficiaries as $index => $beneficiary)
                        <tr>
                            <td>{{ $index + 1 }}</td>
                            <td>{{ $beneficiary->name }}</td>
                            <td>{{ $beneficiary->country }}</td>
                            <td>{{ $beneficiary->bank_name }}</td>
                            <td>{{ $beneficiary->account_number }}</td>
                            <td>{{ $beneficiary->swift_code }}</td>
                            <td>
                                <div class="btn-group btn-group-sm" role="group">
                                    <a href="{{ route('beneficiaries.show', $beneficiary) }}" class="btn btn-info">
                                        <i class="bi bi-eye"></i>
                                    </a>
                                    <a href="{{ route('beneficiaries.edit', $beneficiary) }}" class="btn btn-warning">
                                        <i class="bi bi-pencil"></i>
                                    </a>
                                    <button type="button" class="btn btn-danger" data-bs-toggle="modal" data-bs-target="#deleteModal{{ $beneficiary->id }}">
                                        <i class="bi bi-trash"></i>
                                    </button>
                                </div>
                                
                                <!-- Delete Modal -->
                                <div class="modal fade" id="deleteModal{{ $beneficiary->id }}" tabindex="-1" aria-labelledby="deleteModalLabel{{ $beneficiary->id }}" aria-hidden="true">
                                    <div class="modal-dialog">
                                        <div class="modal-content">
                                            <div class="modal-header">
                                                <h5 class="modal-title" id="deleteModalLabel{{ $beneficiary->id }}">تأكيد الحذف</h5>
                                                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                                            </div>
                                            <div class="modal-body">
                                                هل أنت متأكد من رغبتك في حذف المستفيد "{{ $beneficiary->name }}"؟
                                            </div>
                                            <div class="modal-footer">
                                                <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">إلغاء</button>
                                                <form action="{{ route('beneficiaries.destroy', $beneficiary) }}" method="POST">
                                                    @csrf
                                                    @method('DELETE')
                                                    <button type="submit" class="btn btn-danger">حذف</button>
                                                </form>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </td>
                        </tr>
                    @empty
                        <tr>
                            <td colspan="7" class="text-center">لا يوجد مستفيدين</td>
                        </tr>
                    @endforelse
                </tbody>
            </table>
        </div>
        
        <div class="d-flex justify-content-center mt-4">
            {{ $beneficiaries->links() }}
        </div>
    </div>
</div>

<!-- Countries Map -->
<div class="row mt-4">
    <div class="col-md-7">
        <div class="card">
            <div class="card-header">
                <h5 class="mb-0">توزيع المستفيدين حسب الدولة</h5>
            </div>
            <div class="card-body">
                <div class="table-responsive">
                    <table class="table table-sm">
                        <thead>
                            <tr>
                                <th>الدولة</th>
                                <th>عدد المستفيدين</th>
                                <th>النسبة</th>
                            </tr>
                        </thead>
                        <tbody>
                        @forelse($countryStats ?? [] as $countryStat)
                                <tr>
                                    <td>{{ $countryStat->country }}</td>
                                    <td>{{ $countryStat->count }}</td>
                                    <td>
                                        <div class="progress">
                                            <div class="progress-bar" role="progressbar" style="width: {{ $countryStat->percentage }}%;" aria-valuenow="{{ $countryStat->percentage }}" aria-valuemin="0" aria-valuemax="100">{{ $countryStat->percentage }}%</div>
                                        </div>
                                    </td>
                                </tr>
                            @empty
                                <tr>
                                    <td colspan="3" class="text-center">لا توجد إحصائيات متاحة.</td>
                                </tr>
                            @endforelse
                        </tbody>
                    </table>
                </div>
            </div>
        </div>
    </div>
    
    <div class="col-md-5">
        <div class="card">
            <div class="card-header">
                <h5 class="mb-0">أحدث المستفيدين</h5>
            </div>
            <div class="card-body">
                <ul class="list-group">
                    @forelse($recentBeneficiaries ?? [] as $beneficiary)
                        <li class="list-group-item">
                            <div class="d-flex justify-content-between align-items-center">
                                <div>
                                    <h6 class="mb-0">{{ $beneficiary->name }}</h6>
                                    <small class="text-muted">{{ $beneficiary->country }} - {{ $beneficiary->bank_name }}</small>
                                </div>
                                <a href="{{ route('beneficiaries.show', $beneficiary) }}" class="btn btn-sm btn-outline-primary">
                                    <i class="bi bi-eye"></i>
                                </a>
                            </div>
                        </li>
                    @empty
                        <li class="list-group-item text-center">لا يوجد مستفيدين حديثين.</li>
                    @endforelse
                </ul>
            </div>
        </div>
    </div>
</div>
@endsection