@extends('layouts.app')

@section('title', 'الشركات - نظام إدارة الحوالات الخارجية')

@section('page-title', 'الشركات')

@section('page-actions')
<a href="{{ route('companies.create') }}" class="btn btn-primary">
    <i class="bi bi-plus-circle"></i> إضافة شركة جديدة
</a>
@endsection

@section('content')
<div class="card">
    <div class="card-header">
        <div class="row">
            <div class="col-md-6">
                <h5 class="mb-0">قائمة الشركات</h5>
            </div>
            <div class="col-md-6">
                <form method="GET" action="{{ route('companies.index') }}" class="d-flex">
                    <input type="text" name="search" class="form-control form-control-sm me-2" placeholder="بحث..." value="{{ request('search') }}">
                    <button type="submit" class="btn btn-sm btn-primary">
                        <i class="bi bi-search"></i>
                    </button>
                </form>
            </div>
        </div>
    </div>
    <div class="card-body">
        <div class="table-responsive">
            <table class="table table-hover">
                <thead>
                    <tr>
                        <th>#</th>
                        <th>اسم الشركة</th>
                        <th>رقم التسجيل</th>
                        <th>الرقم الضريبي</th>
                        <th>البريد الإلكتروني</th>
                        <th>عدد الحسابات</th>
                        <th>الإجراءات</th>
                    </tr>
                </thead>
                <tbody>
                    @forelse($companies as $index => $company)
                        <tr>
                            <td>{{ $index + 1 }}</td>
                            <td>{{ $company->name }}</td>
                            <td>{{ $company->registration_number }}</td>
                            <td>{{ $company->tax_number }}</td>
                            <td>{{ $company->email }}</td>
                            <td>{{ $company->bankAccounts->count() }}</td>
                            <td>
                                <div class="btn-group btn-group-sm" role="group">
                                    <a href="{{ route('companies.show', $company) }}" class="btn btn-info">
                                        <i class="bi bi-eye"></i>
                                    </a>
                                    <a href="{{ route('companies.edit', $company) }}" class="btn btn-warning">
                                        <i class="bi bi-pencil"></i>
                                    </a>
                                    <button type="button" class="btn btn-danger" data-bs-toggle="modal" data-bs-target="#deleteModal{{ $company->id }}">
                                        <i class="bi bi-trash"></i>
                                    </button>
                                </div>
                                
                                <!-- Delete Modal -->
                                <div class="modal fade" id="deleteModal{{ $company->id }}" tabindex="-1" aria-labelledby="deleteModalLabel{{ $company->id }}" aria-hidden="true">
                                    <div class="modal-dialog">
                                        <div class="modal-content">
                                            <div class="modal-header">
                                                <h5 class="modal-title" id="deleteModalLabel{{ $company->id }}">تأكيد الحذف</h5>
                                                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                                            </div>
                                            <div class="modal-body">
                                                هل أنت متأكد من رغبتك في حذف الشركة "{{ $company->name }}"؟
                                            </div>
                                            <div class="modal-footer">
                                                <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">إلغاء</button>
                                                <form action="{{ route('companies.destroy', $company) }}" method="POST">
                                                    @csrf
                                                    @method('DELETE')
                                                    <button type="submit" class="btn btn-danger">حذف</button>
                                                </form>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </td>
                        </tr>
                    @empty
                        <tr>
                            <td colspan="7" class="text-center">لا توجد شركات</td>
                        </tr>
                    @endforelse
                </tbody>
            </table>
        </div>
        
        <div class="d-flex justify-content-center mt-4">
            {{ $companies->links() }}
        </div>
    </div>
</div>

<!-- Quick Stats -->
<div class="row mt-4">
    <div class="col-md-12">
        <div class="card">
            <div class="card-header">
                <h5 class="mb-0">إحصائيات الحسابات المصرفية</h5>
            </div>
            <div class="card-body">
                <div class="row">
                    @forelse($bankStats ?? [] as $bankStat)
                        <div class="col-md-3 mb-3">
                            <div class="card">
                                <div class="card-body">
                                    <h5 class="card-title">{{ $bankStat->name }}</h5>
                                    <p class="card-text">
                                        <span class="h4">{{ $bankStat->accounts_count }}</span> حساب
                                    </p>
                                </div>
                            </div>
                        </div>
                    @empty
                        <div class="col-12">
                            <div class="alert alert-info">
                                لا توجد إحصائيات متاحة.
                            </div>
                        </div>
                    @endforelse
                </div>
            </div>
        </div>
    </div>
</div>
@endsection