@extends('layouts.app')

@section('title', 'لوحة التحكم - نظام إدارة الحوالات الخارجية')

@section('page-title', 'لوحة التحكم')

@section('content')
<div class="row">
    <div class="col-md-3">
        <div class="card text-bg-primary">
            <div class="card-body">
                <div class="d-flex justify-content-between align-items-center">
                    <div>
                        <h6 class="card-title">الحوالات</h6>
                        <h2 class="mb-0">{{ $transfersCount }}</h2>
                    </div>
                    <i class="bi bi-currency-exchange fs-1"></i>
                </div>
                <a href="{{ route('transfers.index') }}" class="text-white small">عرض الكل <i class="bi bi-arrow-left"></i></a>
            </div>
        </div>
    </div>
    
    <div class="col-md-3">
        <div class="card text-bg-success">
            <div class="card-body">
                <div class="d-flex justify-content-between align-items-center">
                    <div>
                        <h6 class="card-title">الشركات</h6>
                        <h2 class="mb-0">{{ $companiesCount }}</h2>
                    </div>
                    <i class="bi bi-building fs-1"></i>
                </div>
                <a href="{{ route('companies.index') }}" class="text-white small">عرض الكل <i class="bi bi-arrow-left"></i></a>
            </div>
        </div>
    </div>
    
    <div class="col-md-3">
        <div class="card text-bg-info">
            <div class="card-body">
                <div class="d-flex justify-content-between align-items-center">
                    <div>
                        <h6 class="card-title">المستفيدين</h6>
                        <h2 class="mb-0">{{ $beneficiariesCount }}</h2>
                    </div>
                    <i class="bi bi-people fs-1"></i>
                </div>
                <a href="{{ route('beneficiaries.index') }}" class="text-white small">عرض الكل <i class="bi bi-arrow-left"></i></a>
            </div>
        </div>
    </div>
    
    <div class="col-md-3">
        <div class="card text-bg-warning">
            <div class="card-body">
                <div class="d-flex justify-content-between align-items-center">
                    <div>
                        <h6 class="card-title">الوثائق</h6>
                        <h2 class="mb-0">{{ $documentsCount }}</h2>
                    </div>
                    <i class="bi bi-file-earmark-text fs-1"></i>
                </div>
            </div>
        </div>
    </div>
</div>

<div class="row mt-4">
    <div class="col-md-6">
        <div class="card">
            <div class="card-header d-flex justify-content-between align-items-center">
                <h5 class="mb-0">آخر الحوالات</h5>
                <a href="{{ route('transfers.create') }}" class="btn btn-sm btn-primary">إنشاء حوالة جديدة</a>
            </div>
            <div class="card-body">
                <div class="table-responsive">
                    <table class="table table-hover">
                        <thead>
                            <tr>
                                <th>الرقم المرجعي</th>
                                <th>المبلغ</th>
                                <th>المستفيد</th>
                                <th>الحالة</th>
                                <th>التاريخ</th>
                            </tr>
                        </thead>
                        <tbody>
                            @forelse($recentTransfers as $transfer)
                                <tr>
                                    <td>{{ $transfer->reference_number }}</td>
                                    <td>{{ number_format($transfer->amount, 2) }} {{ $transfer->currency }}</td>
                                    <td>{{ $transfer->beneficiary->name }}</td>
                                    <td>
                                        @if($transfer->status == 'draft')
                                            <span class="badge bg-secondary">مسودة</span>
                                        @elseif($transfer->status == 'pending')
                                            <span class="badge bg-warning">قيد المعالجة</span>
                                        @elseif($transfer->status == 'approved')
                                            <span class="badge bg-success">موافق عليها</span>
                                        @elseif($transfer->status == 'rejected')
                                            <span class="badge bg-danger">مرفوضة</span>
                                        @elseif($transfer->status == 'completed')
                                            <span class="badge bg-primary">مكتملة</span>
                                        @endif
                                    </td>
                                    <td>{{ $transfer->created_at->format('Y-m-d') }}</td>
                                </tr>
                            @empty
                                <tr>
                                    <td colspan="5" class="text-center">لا توجد حوالات حتى الآن</td>
                                </tr>
                            @endforelse
                        </tbody>
                    </table>
                </div>
            </div>
        </div>
    </div>
    
    <div class="col-md-6">
        <div class="card">
            <div class="card-header d-flex justify-content-between align-items-center">
                <h5 class="mb-0">آخر المستفيدين</h5>
                <a href="{{ route('beneficiaries.create') }}" class="btn btn-sm btn-primary">إضافة مستفيد جديد</a>
            </div>
            <div class="card-body">
                <div class="table-responsive">
                    <table class="table table-hover">
                        <thead>
                            <tr>
                                <th>الاسم</th>
                                <th>الدولة</th>
                                <th>المصرف</th>
                                <th>تاريخ الإضافة</th>
                            </tr>
                        </thead>
                        <tbody>
                            @forelse($recentBeneficiaries as $beneficiary)
                                <tr>
                                    <td>{{ $beneficiary->name }}</td>
                                    <td>{{ $beneficiary->country }}</td>
                                    <td>{{ $beneficiary->bank_name }}</td>
                                    <td>{{ $beneficiary->created_at->format('Y-m-d') }}</td>
                                </tr>
                            @empty
                                <tr>
                                    <td colspan="4" class="text-center">لا يوجد مستفيدين حتى الآن</td>
                                </tr>
                            @endforelse
                        </tbody>
                    </table>
                </div>
            </div>
        </div>
    </div>
</div>
@endsection