@extends('layouts.app')

@section('title', 'إضافة نموذج جديد - نظام إدارة الحوالات الخارجية')

@section('page-title', 'إضافة نموذج جديد')

@section('page-actions')
<a href="{{ route('templates.index') }}" class="btn btn-secondary">
    <i class="bi bi-arrow-right"></i> العودة إلى النماذج
</a>
@endsection

@section('content')
<div class="row">
    <div class="col-md-8">
        <div class="card">
            <div class="card-header">
                <h5 class="mb-0">معلومات النموذج</h5>
            </div>
            <div class="card-body">
                <form action="{{ route('templates.store') }}" method="POST" enctype="multipart/form-data">
                    @csrf
                    
                    <div class="row mb-3">
                        <div class="col-md-6">
                            <label for="name" class="form-label">اسم النموذج <span class="text-danger">*</span></label>
                            <input type="text" id="name" name="name" class="form-control @error('name') is-invalid @enderror" value="{{ old('name') }}" required>
                            @error('name')
                                <div class="invalid-feedback">{{ $message }}</div>
                            @enderror
                        </div>
                        
                        <div class="col-md-6">
                            <label for="bank_id" class="form-label">المصرف <span class="text-danger">*</span></label>
                            <select id="bank_id" name="bank_id" class="form-select @error('bank_id') is-invalid @enderror" required>
                                <option value="">-- اختر المصرف --</option>
                                @foreach($banks as $bank)
                                    <option value="{{ $bank->id }}" {{ old('bank_id', request('bank_id')) == $bank->id ? 'selected' : '' }}>{{ $bank->name }}</option>
                                @endforeach
                            </select>
                            @error('bank_id')
                                <div class="invalid-feedback">{{ $message }}</div>
                            @enderror
                        </div>
                    </div>
                    
                    <div class="mb-3">
                        <label for="template_type" class="form-label">نوع النموذج <span class="text-danger">*</span></label>
                        <select id="template_type" name="template_type" class="form-select @error('template_type') is-invalid @enderror" required>
                            <option value="">-- اختر النوع --</option>
                            <option value="transfer_request" {{ old('template_type') == 'transfer_request' ? 'selected' : '' }}>طلب تحويل</option>
                            <option value="currency_window" {{ old('template_type') == 'currency_window' ? 'selected' : '' }}>نافذة العملة</option>
                            <option value="covenant" {{ old('template_type') == 'covenant' ? 'selected' : '' }}>تعهد</option>
                            <option value="confirmation" {{ old('template_type') == 'confirmation' ? 'selected' : '' }}>تأكيد</option>
                        </select>
                        @error('template_type')
                            <div class="invalid-feedback">{{ $message }}</div>
                        @enderror
                    </div>
                    
                    <div class="mb-3">
                        <label for="description" class="form-label">وصف النموذج</label>
                        <textarea id="description" name="description" class="form-control @error('description') is-invalid @enderror" rows="2">{{ old('description') }}</textarea>
                        @error('description')
                            <div class="invalid-feedback">{{ $message }}</div>
                        @enderror
                    </div>
                    
                    <div class="mb-4">
                        <label for="template_file" class="form-label">ملف النموذج <span class="text-danger">*</span></label>
                        <input type="file" id="template_file" name="template_file" class="form-control @error('template_file') is-invalid @enderror" accept=".doc,.docx" required>
                        @error('template_file')
                            <div class="invalid-feedback">{{ $message }}</div>
                        @enderror
                        <div class="form-text">الصيغة المسموح بها: DOC, DOCX. الحجم الأقصى: 5MB</div>
                    </div>
                    
                    <div class="d-grid gap-2">
                        <button type="submit" class="btn btn-primary">
                            <i class="bi bi-save"></i> حفظ النموذج
                        </button>
                    </div>
                </form>
            </div>
        </div>
    </div>
    
    <div class="col-md-4">
        <div class="card mb-4">
            <div class="card-header">
                <h5 class="mb-0">إرشادات النموذج</h5>
            </div>
            <div class="card-body">
                <p>يجب أن يكون النموذج بصيغة Word (DOCX) ويحتوي على المتغيرات التالية:</p>
                
                <div class="alert alert-info">
                    <h6>متغيرات المستند</h6>
                    <p class="mb-1">يجب أن تكون المتغيرات بالصيغة: <code>${variable_name}</code></p>
                </div>
                
                <h6 class="mt-3">المتغيرات الشائعة:</h6>
                <ul class="small">
                    <li><code>${transfer_date}</code> - تاريخ التحويل</li>
                    <li><code>${reference_number}</code> - الرقم المرجعي</li>
                    <li><code>${company_name}</code> - اسم الشركة</li>
                    <li><code>${beneficiary_name}</code> - اسم المستفيد</li>
                    <li><code>${amount}</code> - المبلغ</li>
                    <li><code>${amount_in_words}</code> - المبلغ كتابة</li>
                    <li><code>${currency}</code> - العملة</li>
                    <li><code>${purpose}</code> - الغرض من التحويل</li>
                    <li><code>${bank_name}</code> - اسم المصرف</li>
                    <li><code>${account_number}</code> - رقم الحساب</li>
                    <li><code>${iban}</code> - رقم الحساب الدولي</li>
                    <li><code>${invoice_number}</code> - رقم الفاتورة</li>
                    <li><code>${invoice_date}</code> - تاريخ الفاتورة</li>
                    <li><code>${current_date}</code> - التاريخ الحالي</li>
                </ul>
                
                <p class="mt-3">للاطلاع على قائمة كاملة بالمتغيرات المتاحة، يرجى الرجوع إلى الوثائق.</p>
            </div>
        </div>
    </div>
</div>
@endsection