@extends('layouts.app')

@section('title', 'تعديل النموذج - نظام إدارة الحوالات الخارجية')

@section('page-title', 'تعديل النموذج')

@section('page-actions')
<a href="{{ route('templates.index') }}" class="btn btn-secondary">
    <i class="bi bi-arrow-right"></i> العودة إلى النماذج
</a>
@endsection

@section('content')
<div class="row">
    <div class="col-md-8">
        <div class="card">
            <div class="card-header">
                <h5 class="mb-0">معلومات النموذج</h5>
            </div>
            <div class="card-body">
                <form action="{{ route('templates.update', $template) }}" method="POST" enctype="multipart/form-data">
                    @csrf
                    @method('PUT')
                    
                    <div class="row mb-3">
                        <div class="col-md-6">
                            <label for="name" class="form-label">اسم النموذج <span class="text-danger">*</span></label>
                            <input type="text" id="name" name="name" class="form-control @error('name') is-invalid @enderror" value="{{ old('name', $template->name) }}" required>
                            @error('name')
                                <div class="invalid-feedback">{{ $message }}</div>
                            @enderror
                        </div>
                        
                        <div class="col-md-6">
                            <label for="bank_id" class="form-label">المصرف <span class="text-danger">*</span></label>
                            <select id="bank_id" name="bank_id" class="form-select @error('bank_id') is-invalid @enderror" required>
                                <option value="">-- اختر المصرف --</option>
                                @foreach($banks as $bank)
                                    <option value="{{ $bank->id }}" {{ old('bank_id', $template->bank_id) == $bank->id ? 'selected' : '' }}>{{ $bank->name }}</option>
                                @endforeach
                            </select>
                            @error('bank_id')
                                <div class="invalid-feedback">{{ $message }}</div>
                            @enderror
                        </div>
                    </div>
                    
                    <div class="mb-3">
                        <label for="template_type" class="form-label">نوع النموذج <span class="text-danger">*</span></label>
                        <select id="template_type" name="template_type" class="form-select @error('template_type') is-invalid @enderror" required>
                            <option value="">-- اختر النوع --</option>
                            <option value="transfer_request" {{ old('template_type', $template->template_type) == 'transfer_request' ? 'selected' : '' }}>طلب تحويل</option>
                            <option value="currency_window" {{ old('template_type', $template->template_type) == 'currency_window' ? 'selected' : '' }}>نافذة العملة</option>
                            <option value="covenant" {{ old('template_type', $template->template_type) == 'covenant' ? 'selected' : '' }}>تعهد</option>
                            <option value="confirmation" {{ old('template_type', $template->template_type) == 'confirmation' ? 'selected' : '' }}>تأكيد</option>
                        </select>
                        @error('template_type')
                            <div class="invalid-feedback">{{ $message }}</div>
                        @enderror
                    </div>
                    
                    <div class="mb-3">
                        <label for="description" class="form-label">وصف النموذج</label>
                        <textarea id="description" name="description" class="form-control @error('description') is-invalid @enderror" rows="2">{{ old('description', $template->description) }}</textarea>
                        @error('description')
                            <div class="invalid-feedback">{{ $message }}</div>
                        @enderror
                    </div>
                    
                    <div class="mb-4">
                        <label for="template_file" class="form-label">ملف النموذج</label>
                        <input type="file" id="template_file" name="template_file" class="form-control @error('template_file') is-invalid @enderror" accept=".doc,.docx">
                        @error('template_file')
                            <div class="invalid-feedback">{{ $message }}</div>
                        @enderror
                        <div class="form-text">
                            الملف الحالي: {{ basename($template->file_path) }}<br>
                            الصيغة المسموح بها: DOC, DOCX. الحجم الأقصى: 5MB
                        </div>
                    </div>
                    
                    <div class="d-grid gap-2">
                        <button type="submit" class="btn btn-primary">
                            <i class="bi bi-save"></i> حفظ التغييرات
                        </button>
                    </div>
                </form>
            </div>
        </div>
    </div>
    
    <div class="col-md-4">
        <div class="card mb-4">
            <div class="card-header">
                <h5 class="mb-0">معلومات النموذج</h5>
            </div>
            <div class="card-body">
                <p><strong>تاريخ الإضافة:</strong> {{ $template->created_at->format('Y-m-d H:i') }}</p>
                <p><strong>آخر تحديث:</strong> {{ $template->updated_at->format('Y-m-d H:i') }}</p>
                <p><strong>المصرف:</strong> {{ $template->bank->name }}</p>
                <p><strong>النوع:</strong> 
                    @if($template->template_type == 'transfer_request')
                        طلب تحويل
                    @elseif($template->template_type == 'currency_window')
                        نافذة العملة
                    @elseif($template->template_type == 'covenant')
                        تعهد
                    @elseif($template->template_type == 'confirmation')
                        تأكيد
                    @endif
                </p>
                
                <hr>
                
                <div class="d-grid gap-2">
                    <a href="{{ Storage::url($template->file_path) }}" class="btn btn-outline-primary" target="_blank">
                        <i class="bi bi-download"></i> تنزيل الملف الحالي
                    </a>
                </div>
            </div>
        </div>
        
        <div class="card">
            <div class="card-header">
                <h5 class="mb-0">إرشادات النموذج</h5>
            </div>
            <div class="card-body">
                <div class="alert alert-warning">
                    <i class="bi bi-exclamation-triangle-fill me-2"></i>
                    تحديث ملف النموذج اختياري. إذا لم تقم بتحميل ملف جديد، سيتم الاحتفاظ بالملف الحالي.
                </div>
                
                <p>يجب أن يكون النموذج بصيغة Word (DOCX) ويحتوي على المتغيرات المناسبة.</p>
            </div>
        </div>
    </div>
</div>
@endsection