@extends('layouts.app')

@section('title', 'النماذج - نظام إدارة الحوالات الخارجية')

@section('page-title', 'النماذج')

@section('page-actions')
@can('create', App\Models\Template::class)
<a href="{{ route('templates.create') }}" class="btn btn-primary">
    <i class="bi bi-plus-circle"></i> إضافة نموذج جديد
</a>
@endcan
@endsection

@section('content')
<div class="card">
    <div class="card-header">
        <div class="row">
            <div class="col-md-6">
                <h5 class="mb-0">قائمة النماذج</h5>
            </div>
            <div class="col-md-6">
                <form method="GET" action="{{ route('templates.index') }}" class="d-flex">
                    <select name="bank_id" class="form-select form-select-sm me-2">
                        <option value="">كل المصارف</option>
                        @foreach($banks as $bank)
                            <option value="{{ $bank->id }}" {{ request('bank_id') == $bank->id ? 'selected' : '' }}>{{ $bank->name }}</option>
                        @endforeach
                    </select>
                    <select name="type" class="form-select form-select-sm me-2">
                        <option value="">كل الأنواع</option>
                        <option value="transfer_request" {{ request('type') == 'transfer_request' ? 'selected' : '' }}>طلب تحويل</option>
                        <option value="currency_window" {{ request('type') == 'currency_window' ? 'selected' : '' }}>نافذة العملة</option>
                        <option value="covenant" {{ request('type') == 'covenant' ? 'selected' : '' }}>تعهد</option>
                        <option value="confirmation" {{ request('type') == 'confirmation' ? 'selected' : '' }}>تأكيد</option>
                    </select>
                    <button type="submit" class="btn btn-sm btn-primary">
                        <i class="bi bi-filter"></i> تصفية
                    </button>
                </form>
            </div>
        </div>
    </div>
    <div class="card-body">
        <div class="table-responsive">
            <table class="table table-hover">
                <thead>
                    <tr>
                        <th>#</th>
                        <th>اسم النموذج</th>
                        <th>المصرف</th>
                        <th>النوع</th>
                        <th>تاريخ الإضافة</th>
                        <th>الإجراءات</th>
                    </tr>
                </thead>
                <tbody>
                    @forelse($templates as $index => $template)
                        <tr>
                            <td>{{ $index + 1 }}</td>
                            <td>{{ $template->name }}</td>
                            <td>{{ $template->bank->name }}</td>
                            <td>
                                @if($template->template_type == 'transfer_request')
                                    <span class="badge bg-primary">طلب تحويل</span>
                                @elseif($template->template_type == 'currency_window')
                                    <span class="badge bg-success">نافذة العملة</span>
                                @elseif($template->template_type == 'covenant')
                                    <span class="badge bg-warning">تعهد</span>
                                @elseif($template->template_type == 'confirmation')
                                    <span class="badge bg-info">تأكيد</span>
                                @endif
                            </td>
                            <td>{{ $template->created_at->format('Y-m-d') }}</td>
                            <td>
                                <div class="btn-group btn-group-sm" role="group">
                                    <a href="{{ Storage::url($template->file_path) }}" class="btn btn-primary" target="_blank">
                                        <i class="bi bi-eye"></i> عرض
                                    </a>
                                    @can('update', $template)
                                    <a href="{{ route('templates.edit', $template) }}" class="btn btn-warning">
                                        <i class="bi bi-pencil"></i>
                                    </a>
                                    @endcan
                                    @can('delete', $template)
                                    <button type="button" class="btn btn-danger" data-bs-toggle="modal" data-bs-target="#deleteModal{{ $template->id }}">
                                        <i class="bi bi-trash"></i>
                                    </button>
                                    @endcan
                                </div>
                                
                                <!-- Delete Modal -->
                                @can('delete', $template)
                                <div class="modal fade" id="deleteModal{{ $template->id }}" tabindex="-1" aria-labelledby="deleteModalLabel{{ $template->id }}" aria-hidden="true">
                                    <div class="modal-dialog">
                                        <div class="modal-content">
                                            <div class="modal-header">
                                                <h5 class="modal-title" id="deleteModalLabel{{ $template->id }}">تأكيد الحذف</h5>
                                                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                                            </div>
                                            <div class="modal-body">
                                                هل أنت متأكد من رغبتك في حذف النموذج "{{ $template->name }}"؟
                                            </div>
                                            <div class="modal-footer">
                                                <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">إلغاء</button>
                                                <form action="{{ route('templates.destroy', $template) }}" method="POST">
                                                    @csrf
                                                    @method('DELETE')
                                                    <button type="submit" class="btn btn-danger">حذف</button>
                                                </form>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                                @endcan
                            </td>
                        </tr>
                    @empty
                        <tr>
                            <td colspan="6" class="text-center">لا توجد نماذج</td>
                        </tr>
                    @endforelse
                </tbody>
            </table>
        </div>
        
        <div class="d-flex justify-content-center mt-4">
            {{ $templates->links() }}
        </div>
    </div>
</div>

<div class="card mt-4">
    <div class="card-header">
        <h5 class="mb-0">أنواع النماذج</h5>
    </div>
    <div class="card-body">
        <div class="row">
            <div class="col-md-6">
                <div class="card mb-3">
                    <div class="card-body">
                        <h5 class="card-title">
                            <span class="badge bg-primary me-2">طلب تحويل</span>
                            Transfer Request
                        </h5>
                        <p class="card-text">
                            نموذج طلب تحويل مبلغ من حساب العميل إلى المستفيد. يتضمن معلومات عن المحول والمستفيد والمبلغ المطلوب تحويله.
                        </p>
                    </div>
                </div>
            </div>
            <div class="col-md-6">
                <div class="card mb-3">
                    <div class="card-body">
                        <h5 class="card-title">
                            <span class="badge bg-success me-2">نافذة العملة</span>
                            Currency Window
                        </h5>
                        <p class="card-text">
                            نموذج طلب شراء عملة أجنبية من خلال نافذة العملة الأجنبية في البنك المركزي العراقي.
                        </p>
                    </div>
                </div>
            </div>
            <div class="col-md-6">
                <div class="card">
                    <div class="card-body">
                        <h5 class="card-title">
                            <span class="badge bg-warning me-2">تعهد</span>
                            Covenant
                        </h5>
                        <p class="card-text">
                            نموذج تعهد من العميل يتضمن إقرار بسلامة مصادر الأموال وعدم التعامل مع الدول المحظورة وتقديم المستندات المطلوبة.
                        </p>
                    </div>
                </div>
            </div>
            <div class="col-md-6">
                <div class="card">
                    <div class="card-body">
                        <h5 class="card-title">
                            <span class="badge bg-info me-2">تأكيد</span>
                            Confirmation
                        </h5>
                        <p class="card-text">
                            نموذج تأكيد من العميل يتضمن تأكيد المعلومات المقدمة والغرض من التحويل.
                        </p>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>
@endsection