@extends('layouts.app')

@section('title', 'الحوالات - نظام إدارة الحوالات الخارجية')

@section('page-title', 'الحوالات')

@section('page-actions')
<a href="{{ route('transfers.create') }}" class="btn btn-primary">
    <i class="bi bi-plus-circle"></i> إنشاء حوالة جديدة
</a>
@endsection

@section('content')
<div class="card">
    <div class="card-header">
        <div class="row">
            <div class="col-md-6">
                <h5 class="mb-0">قائمة الحوالات</h5>
            </div>
            <div class="col-md-6">
                <form method="GET" action="{{ route('transfers.index') }}" class="d-flex">
                    <input type="text" name="search" class="form-control form-control-sm me-2" placeholder="بحث..." value="{{ request('search') }}">
                    <select name="status" class="form-select form-select-sm me-2">
                        <option value="">كل الحالات</option>
                        <option value="draft" {{ request('status') == 'draft' ? 'selected' : '' }}>مسودة</option>
                        <option value="pending" {{ request('status') == 'pending' ? 'selected' : '' }}>قيد المعالجة</option>
                        <option value="approved" {{ request('status') == 'approved' ? 'selected' : '' }}>موافق عليها</option>
                        <option value="rejected" {{ request('status') == 'rejected' ? 'selected' : '' }}>مرفوضة</option>
                        <option value="completed" {{ request('status') == 'completed' ? 'selected' : '' }}>مكتملة</option>
                    </select>
                    <button type="submit" class="btn btn-sm btn-primary">
                        <i class="bi bi-search"></i>
                    </button>
                </form>
            </div>
        </div>
    </div>
    <div class="card-body">
        <div class="table-responsive">
            <table class="table table-hover">
                <thead>
                    <tr>
                        <th>#</th>
                        <th>الرقم المرجعي</th>
                        <th>الشركة المحولة</th>
                        <th>المستفيد</th>
                        <th>المبلغ</th>
                        <th>المصرف</th>
                        <th>التاريخ</th>
                        <th>الحالة</th>
                        <th>الإجراءات</th>
                    </tr>
                </thead>
                <tbody>
                    @forelse($transfers as $index => $transfer)
                        <tr>
                            <td>{{ $index + 1 }}</td>
                            <td>{{ $transfer->reference_number }}</td>
                            <td>{{ $transfer->company->name }}</td>
                            <td>{{ $transfer->beneficiary->name }}</td>
                            <td>{{ number_format($transfer->amount, 2) }} {{ $transfer->currency }}</td>
                            <td>{{ $transfer->bank->name }}</td>
                            <td>{{ $transfer->created_at->format('Y-m-d') }}</td>
                            <td>
                                @if($transfer->status == 'draft')
                                    <span class="badge bg-secondary">مسودة</span>
                                @elseif($transfer->status == 'pending')
                                    <span class="badge bg-warning">قيد المعالجة</span>
                                @elseif($transfer->status == 'approved')
                                    <span class="badge bg-success">موافق عليها</span>
                                @elseif($transfer->status == 'rejected')
                                    <span class="badge bg-danger">مرفوضة</span>
                                @elseif($transfer->status == 'completed')
                                    <span class="badge bg-primary">مكتملة</span>
                                @endif
                            </td>
                            <td>
                                <div class="btn-group btn-group-sm" role="group">
                                    <a href="{{ route('transfers.show', $transfer) }}" class="btn btn-info">
                                        <i class="bi bi-eye"></i>
                                    </a>
                                    @if($transfer->status == 'draft')
                                        <a href="{{ route('transfers.edit', $transfer) }}" class="btn btn-warning">
                                            <i class="bi bi-pencil"></i>
                                        </a>
                                        <button type="button" class="btn btn-danger" data-bs-toggle="modal" data-bs-target="#deleteModal{{ $transfer->id }}">
                                            <i class="bi bi-trash"></i>
                                        </button>
                                    @endif
                                </div>
                                
                                <!-- Delete Modal -->
                                <div class="modal fade" id="deleteModal{{ $transfer->id }}" tabindex="-1" aria-labelledby="deleteModalLabel{{ $transfer->id }}" aria-hidden="true">
                                    <div class="modal-dialog">
                                        <div class="modal-content">
                                            <div class="modal-header">
                                                <h5 class="modal-title" id="deleteModalLabel{{ $transfer->id }}">تأكيد الحذف</h5>
                                                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                                            </div>
                                            <div class="modal-body">
                                                هل أنت متأكد من رغبتك في حذف هذه الحوالة؟
                                            </div>
                                            <div class="modal-footer">
                                                <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">إلغاء</button>
                                                <form action="{{ route('transfers.destroy', $transfer) }}" method="POST">
                                                    @csrf
                                                    @method('DELETE')
                                                    <button type="submit" class="btn btn-danger">حذف</button>
                                                </form>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </td>
                        </tr>
                    @empty
                        <tr>
                            <td colspan="9" class="text-center">لا توجد حوالات</td>
                        </tr>
                    @endforelse
                </tbody>
            </table>
        </div>
        
        <div class="d-flex justify-content-center mt-4">
            {{ $transfers->links() }}
        </div>
    </div>
</div>

<!-- Status Stats Cards -->
<div class="row mt-4">
    <div class="col-md-12">
        <div class="card">
            <div class="card-header">
                <h5 class="mb-0">إحصائيات الحوالات حسب الحالة</h5>
            </div>
            <div class="card-body">
                <div class="row">
                    <div class="col">
                        <div class="card bg-secondary text-white">
                            <div class="card-body text-center">
                                <h6 class="mb-0">مسودة</h6>
                                <h3 class="mb-0">{{ $draftCount ?? 0 }}</h3>
                            </div>
                        </div>
                    </div>
                    <div class="col">
                        <div class="card bg-warning text-dark">
                            <div class="card-body text-center">
                                <h6 class="mb-0">قيد المعالجة</h6>
                                <h3 class="mb-0">{{ $pendingCount ?? 0 }}</h3>
                            </div>
                        </div>
                    </div>
                    <div class="col">
                        <div class="card bg-success text-white">
                            <div class="card-body text-center">
                                <h6 class="mb-0">موافق عليها</h6>
                                <h3 class="mb-0">{{ $approvedCount ?? 0 }}</h3>
                            </div>
                        </div>
                    </div>
                    <div class="col">
                        <div class="card bg-danger text-white">
                            <div class="card-body text-center">
                                <h6 class="mb-0">مرفوضة</h6>
                                <h3 class="mb-0">{{ $rejectedCount ?? 0 }}</h3>
                            </div>
                        </div>
                    </div>
                    <div class="col">
                        <div class="card bg-primary text-white">
                            <div class="card-body text-center">
                                <h6 class="mb-0">مكتملة</h6>
                                <h3 class="mb-0">{{ $completedCount ?? 0 }}</h3>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>
@endsection